==> foundation-ui-components-1.1.0.tgz: package/src/common/radiogroup/NsRadioGroup.stories.tsx <==

import type { StoryObj, Meta } from '@storybook/react';
import { within, userEvent } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { NsRadioGroup } from './'
import { FoundationTheme } from '@nuskin/foundation-theme';

type ComponentType = typeof NsRadioGroup;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsRadioGroup,
    title: 'Components/Inputs/NsRadioGroup',
    argTypes: {
        disable: {
            description:
                'Indicates whether the radio button is enabled/disabled',

        },
        items: {
            description:
                'Value of the component to be emitted when selected.',
        },
        name: {
            description:
                'Name of the component',

        },
        label: {
            description:
                'Label of the radio group',

        },
        color: {
            description:
                'Color of the radio button',

        },
        size: {
            description:
                'Margin Left for Additional Slot text',

        },
        labelFontSize: {
            description:
                'Used to change font-size of the label'
        },
        additionalSlot: {
            description:
                'An additional slot allows for more text',

        }
    },
} as MetaStory;

export const RadioGroup: Story = {
    args: {
        disable: false,
        items: [
            {
                id: 'individual',
                label: `Vendeur à domicile indépendant mandataire (The VDI mandataire
                     enters into sales or service agreements 
                    with customers in the name and on behalf of the company.
                     His remuneration will be based on commissions made
                     on the sales of products to customers.)`,
                value: 'individual',
            },
            {
                id: ' retailer',
                label: `Vendeur à domicile indépendant acheteur-revendeur
                 (The VDI acheteur-revendeur sells the company's products in his own name and behalf. 
                 His remuneration will be based on commissions and on the margins made on the sales of
                  products to customers.)`,
                value: 'retailer',
            },
        ],
        name: 'test',
        label: 'I choose to signup as',
        color: '#272525' as FoundationTheme.PaletteColors,
        additionalSlot: 'An additional slot allows for more text',
        size: 10,
        labelFontSize: 16,
        additionalProps: {
            testid: 'radio-group',
        },
    },
    play: async ({ canvasElement }) => {
        const canvas = within(canvasElement);
        await userEvent.hover(canvas.getByTestId('radio-group'));
        await expect(
            canvas.getByText(
                'Vendeur à domicile indépendant mandataire (The VDI mandataire enters into sales or service agreements with customers in the name and on behalf of the company. His remuneration will be based on commissions made on the sales of products to customers.)'
            )
        ).toBeInTheDocument();
    },
};

==> foundation-ui-components-1.30.1.tgz: package/src/common/radiogroup/NsRadioGroup.stories.tsx <==
import type { StoryObj, Meta } from '@storybook/react';
import { within, userEvent } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { NsRadioGroup } from './';
import { FoundationTheme } from '@nuskin/foundation-theme';

type ComponentType = typeof NsRadioGroup;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsRadioGroup,
    title: 'Components/Inputs/NsRadioGroup',
    argTypes: {
        disable: {
            description: 'Indicates whether the radio button is enabled/disabled',
        },
        items: {
            description: 'Value of the component to be emitted when selected.',
        },
        name: {
            description: 'Name of the component',
        },
        label: {
            description: 'Label of the radio group',
        },
        color: {
            description: 'Color of the radio button',
        },
        size: {
            description: 'Margin Left for Additional Slot text',
        },
        labelFontSize: {
            description: 'Used to change font-size of the label',
        },
        helperText: {
            description: 'An additional slot allows for more text',
        },
    },
} as MetaStory;

export const RadioGroup: Story = {
    args: {
        disable: false,
        items: [
            {
                id: 'individual',
                label: `Vendeur à domicile indépendant mandataire (The VDI mandataire
                     enters into sales or service agreements
                    with customers in the name and on behalf of the company.
                     His remuneration will be based on commissions made
                     on the sales of products to customers.)`,
                value: 'individual',
            },
            {
                id: ' retailer',
                label: `Vendeur à domicile indépendant acheteur-revendeur
                 (The VDI acheteur-revendeur sells the company's products in his own name and behalf.
                 His remuneration will be based on commissions and on the margins made on the sales of
                  products to customers.)`,
                value: 'retailer',
            },
        ],
        name: 'test',
        label: 'I choose to signup as',
        color: '#272525' as FoundationTheme.PaletteColors,
        helperText: 'An additional slot allows for more text',
        size: 10,
        labelFontSize: 16,
        additionalProps: {
            testid: 'radio-group',
        },
    },
    play: async ({ canvasElement }) => {
        const canvas = within(canvasElement);
        await userEvent.hover(canvas.getByTestId('radio-group'));
        await expect(
            canvas.getByText(
                // eslint-disable-next-line max-len
                'Vendeur à domicile indépendant mandataire (The VDI mandataire enters into sales or service agreements with customers in the name and on behalf of the company. His remuneration will be based on commissions made on the sales of products to customers.)'
            )
        ).toBeInTheDocument();
    },
};
